CA27_Cl01.html
open | /cms/logout/ |
open | /admin/ |
type | id_username | admin
type | id_password | admin
clickAndWait | //input[@value='Iniciar sesión'] |
clickAndWait | link=Panoramic views |
clickAndWait | link=Añadir panoramic view |
type | id_name | Nuevo
type | id_external_url | www.nuevo.com
clickAndWait | _continue |
clickAndWait | link=Borrar |
verifyTextPresent | exact:¿Está seguro? |
verifyTextPresent | exact:¿Está seguro de que quiere borrar los panoramic view "Nuevo (http://www.nuevo.com/)"? Se borrarán los siguientes objetos relacionados: |
verifyTextPresent | Panoramic view: Nuevo (http://www.nuevo.com/) |
verifyTextPresent | Base multimedia: Nuevo |
clickAndWait | //input[@value='Sí, estoy seguro'] |
verifyTextPresent | Se eliminó con éxito el panoramic view "Nuevo (http://www.nuevo.com/)". |
clickAndWait | link=Terminar sesión |